@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12795 2021-03-10 17:23:54Z Lavender $
+# $Id: models.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2020 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-03-11 01:23:54 +0800 (Thu, 11 Mar 2021) $
-# $Revision: 12795 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import datetime
 
@@ -444,7 +444,7 @@ class BonusSettings(SingletonModel):
         verbose_name=_("Expiry days(-1 is no limit)"), default=-1, validators=[MinValueValidator(-1),],)
     
 # https://code.nuwainfo.com/trac/Mercurius/ticket/3301#ticket
-CommunicationEventType = get_model('customer', 'CommunicationEventType')
+CommunicationEventType = get_model('communication', 'CommunicationEventType')
 RawHTML = get_model('promotions', 'RawHTML')
 
 def getATMInfo():
