@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 13368 2022-01-01 08:52:58Z Lavender $
+# $Id: __init__.py 13369 2022-01-08 11:52:12Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2022-01-01 16:52:58 +0800 (週六, 01 一月 2022) $
-# $Revision: 13368 $
+# $Date: 2022-01-08 19:52:12 +0800 (週六, 08 一月 2022) $
+# $Revision: 13369 $
 
 import os
 
@@ -34,19 +34,21 @@ else:
 if not STATIC_DIR:
     STATIC_DIR = os.path.join(settings.BASE_DIR, "static")
 
-if not hasattr(settings, "TEMPLATE_EDITOR_TEMPLATE_DIR"):
+if not hasattr(settings, "TEMPLATE_EDITOR_TEMPLATE_DIRS"):
     # 找尋 settings.py 的 TEMPLATES 內的設定當 TEMPLATE_DIR
-    TEMPLATE_DIR = None
+    TEMPLATE_DIRS = None
     if hasattr(settings, "TEMPLATES"):
         try:
-            TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
+            TEMPLATE_DIRS = settings.TEMPLATES[0]['DIRS']
         except Exception as e:
             pass
 
-    if not TEMPLATE_DIR:
-        TEMPLATE_DIR = os.path.join(settings.BASE_DIR, "templates")
+    if not TEMPLATE_DIRS:
+        TEMPLATE_DIRS = [
+            os.path.join(settings.BASE_DIR, "templates"),
+        ]
 else:
-    TEMPLATE_DIR = settings.TEMPLATE_EDITOR_TEMPLATE_DIR
+    TEMPLATE_DIRS = settings.TEMPLATE_EDITOR_TEMPLATE_DIRS
 
 BACKUP_DIR_NAME = "_Iuno.template_editor_backup" 
 
